@@ -843,7 +843,7 @@ ev_view_presentation_set_cursor (EvViewPresentation *pview,
 	gdk_window_set_cursor (gtk_widget_get_window (widget), cursor);
 	gdk_flush ();
 	if (cursor)
-		gdk_cursor_unref (cursor);
+		g_object_unref (cursor);
 }
 
 static void
